Skip to main contentCrate camel_language_api
Source pub use error::LanguageError;
- error
- Expression
- Evaluates to a Value against an Exchange.
- Language
- A Language factory: produces Expression and Predicate objects.
- MutatingExpression
- Expression that may modify the Exchange during evaluation.
Changes to headers, properties, or body are propagated back.
- MutatingPredicate
- Predicate that may modify the Exchange during evaluation.
Changes to headers, properties, or body are propagated back.
- Predicate
- Evaluates to bool against an Exchange.